@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2014 Conrad Sanderson
-// Copyright (C) 2008-2014 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2015 Conrad Sanderson
+// Copyright (C) 2008-2015 NICTA (www.nicta.com.au)
 // Copyright (C) 2012-2014 Ryan Curtin
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
@@ -202,6 +202,18 @@ class Mat : public Base< eT, Mat<eT> >
   inline            subview<eT> operator()(const uword in_row1, const uword in_col1, const SizeMat& s);
   inline      const subview<eT> operator()(const uword in_row1, const uword in_col1, const SizeMat& s) const;
   
+  inline       subview<eT> head_rows(const uword N);
+  inline const subview<eT> head_rows(const uword N) const;
+  
+  inline       subview<eT> tail_rows(const uword N);
+  inline const subview<eT> tail_rows(const uword N) const;
+  
+  inline       subview<eT> head_cols(const uword N);
+  inline const subview<eT> head_cols(const uword N) const;
+  
+  inline       subview<eT> tail_cols(const uword N);
+  inline const subview<eT> tail_cols(const uword N) const;
+  
   template<typename T1> arma_inline       subview_elem1<eT,T1> elem(const Base<uword,T1>& a);
   template<typename T1> arma_inline const subview_elem1<eT,T1> elem(const Base<uword,T1>& a) const;
   
@@ -700,6 +712,10 @@ class Mat<eT>::fixed : public Mat<eT>
   
   arma_inline const Mat& operator=(const fixed<fixed_n_rows, fixed_n_cols>& X);
   
+  template<typename T1, typename eop_type> inline const Mat& operator=(const eOp<T1, eop_type>& X);
+  
+  template<typename T1, typename T2, typename eglue_type> inline const Mat& operator=(const eGlue<T1, T2, eglue_type>& X);
+  
   arma_inline const Op< Mat_fixed_type, op_htrans >  t() const;
   arma_inline const Op< Mat_fixed_type, op_htrans > ht() const;
   arma_inline const Op< Mat_fixed_type, op_strans > st() const;
