@@ -196,6 +196,10 @@ class Row<eT>::fixed : public Row<eT>
   
   arma_inline const Row& operator=(const fixed<fixed_n_elem>& X);
     
+  template<typename T1, typename eop_type> inline const Row& operator=(const eOp<T1, eop_type>& X);
+  
+  template<typename T1, typename T2, typename eglue_type> inline const Row& operator=(const eGlue<T1, T2, eglue_type>& X);
+  
   arma_inline const Op< Row_fixed_type, op_htrans >  t() const;
   arma_inline const Op< Row_fixed_type, op_htrans > ht() const;
   arma_inline const Op< Row_fixed_type, op_strans > st() const;
