@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2013 Conrad Sanderson
-// Copyright (C) 2008-2013 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2014 Conrad Sanderson
+// Copyright (C) 2008-2014 NICTA (www.nicta.com.au)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -84,16 +84,9 @@ class gemm_emul_large
       
       for(uword row_A=0; row_A < A_n_rows; ++row_A)
         {
-        //tmp.copy_row(A, row_A);
-        const eT acc0 = op_dot::dot_and_copy_row(A_rowdata, A, row_A, B.colptr(0), A_n_cols);
+        tmp.copy_row(A, row_A);
         
-             if( (use_alpha == false) && (use_beta == false) )  { C.at(row_A,0) =       acc0;                      }
-        else if( (use_alpha == true ) && (use_beta == false) )  { C.at(row_A,0) = alpha*acc0;                      }
-        else if( (use_alpha == false) && (use_beta == true ) )  { C.at(row_A,0) =       acc0 + beta*C.at(row_A,0); }
-        else if( (use_alpha == true ) && (use_beta == true ) )  { C.at(row_A,0) = alpha*acc0 + beta*C.at(row_A,0); }
-
-        //for(uword col_B=0; col_B < B_n_cols; ++col_B)
-        for(uword col_B=1; col_B < B_n_cols; ++col_B)
+        for(uword col_B=0; col_B < B_n_cols; ++col_B)
           {
           const eT acc = op_dot::direct_dot_arma(B_n_rows, A_rowdata, B.colptr(col_B));
           
@@ -190,30 +183,7 @@ class gemm_emul
     arma_extra_debug_sigprint();
     arma_ignore(junk);
     
-    const uword A_n_rows = A.n_rows;
-    const uword A_n_cols = A.n_cols;
-    
-    const uword B_n_rows = B.n_rows;
-    const uword B_n_cols = B.n_cols;
-    
-    if( (A_n_rows <= 4) && (A_n_rows == A_n_cols) && (A_n_rows == B_n_rows) && (B_n_rows == B_n_cols) )
-      {
-      if(do_trans_B == false)
-        {
-        gemm_emul_tinysq<do_trans_A, use_alpha, use_beta>::apply(C, A, B, alpha, beta);
-        }
-      else
-        {
-        Mat<eT> BB(A_n_rows, A_n_rows);
-        op_strans::apply_mat_noalias_tinysq(BB, B);
-        
-        gemm_emul_tinysq<do_trans_A, use_alpha, use_beta>::apply(C, A, BB, alpha, beta);
-        }
-      }
-    else
-      {
-      gemm_emul_large<do_trans_A, do_trans_B, use_alpha, use_beta>::apply(C, A, B, alpha, beta);
-      }
+    gemm_emul_large<do_trans_A, do_trans_B, use_alpha, use_beta>::apply(C, A, B, alpha, beta);
     }
   
   
@@ -247,20 +217,7 @@ class gemm_emul
     const Mat<eT>& AA = (do_trans_A == false) ? A : tmp_A;
     const Mat<eT>& BB = (do_trans_B == false) ? B : tmp_B;
     
-    const uword A_n_rows = AA.n_rows;
-    const uword A_n_cols = AA.n_cols;
-    
-    const uword B_n_rows = BB.n_rows;
-    const uword B_n_cols = BB.n_cols;
-    
-    if( (A_n_rows <= 4) && (A_n_rows == A_n_cols) && (A_n_rows == B_n_rows) && (B_n_rows == B_n_cols) )
-      {
-      gemm_emul_tinysq<false, use_alpha, use_beta>::apply(C, AA, BB, alpha, beta);
-      }
-    else
-      {
-      gemm_emul_large<false, false, use_alpha, use_beta>::apply(C, AA, BB, alpha, beta);
-      }
+    gemm_emul_large<false, false, use_alpha, use_beta>::apply(C, AA, BB, alpha, beta);
     }
 
   };
@@ -284,13 +241,20 @@ class gemm
     {
     arma_extra_debug_sigprint();
     
-    const uword threshold = (is_Mat_fixed<TA>::value && is_Mat_fixed<TB>::value)
-                            ? (is_cx<eT>::yes ? 16u : 64u)
-                            : (is_cx<eT>::yes ? 16u : 48u);
-    
-    if( (A.n_elem <= threshold) && (B.n_elem <= threshold) )
+    if( (A.n_rows <= 4) && (A.n_rows == A.n_cols) && (A.n_rows == B.n_rows) && (B.n_rows == B.n_cols) && (is_cx<eT>::no) ) 
       {
-      gemm_emul<do_trans_A, do_trans_B, use_alpha, use_beta>::apply(C,A,B,alpha,beta);
+      if(do_trans_B == false)
+        {
+        gemm_emul_tinysq<do_trans_A, use_alpha, use_beta>::apply(C, A, B, alpha, beta);
+        }
+      else
+        {
+        Mat<eT> BB(B.n_rows, B.n_rows);
+        
+        op_strans::apply_mat_noalias_tinysq(BB, B);
+        
+        gemm_emul_tinysq<do_trans_A, use_alpha, use_beta>::apply(C, A, BB, alpha, beta);
+        }
       }
     else
       {
